==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_region_instance_group_manager/ComputeRegionInstanceGroupManagerStatusOutputReference.java <==
package com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.821Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeRegionInstanceGroupManager.ComputeRegionInstanceGroupManagerStatusOutputReference")
public class ComputeRegionInstanceGroupManagerStatusOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ComputeRegionInstanceGroupManagerStatusOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ComputeRegionInstanceGroupManagerStatusOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ComputeRegionInstanceGroupManagerStatusOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable getIsStable() {
        return software.amazon.jsii.Kernel.get(this, "isStable", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.IResolvable.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusStatefulList getStateful() {
        return software.amazon.jsii.Kernel.get(this, "stateful", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusStatefulList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusVersionTargetList getVersionTarget() {
        return software.amazon.jsii.Kernel.get(this, "versionTarget", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusVersionTargetList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_region_instance_group_manager/ComputeRegionInstanceGroupManagerStatusOutputReference.java <==
package com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.753Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeRegionInstanceGroupManager.ComputeRegionInstanceGroupManagerStatusOutputReference")
public class ComputeRegionInstanceGroupManagerStatusOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ComputeRegionInstanceGroupManagerStatusOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ComputeRegionInstanceGroupManagerStatusOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ComputeRegionInstanceGroupManagerStatusOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusAllInstancesConfigList getAllInstancesConfig() {
        return software.amazon.jsii.Kernel.get(this, "allInstancesConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusAllInstancesConfigList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IResolvable getIsStable() {
        return software.amazon.jsii.Kernel.get(this, "isStable", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.IResolvable.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusStatefulList getStateful() {
        return software.amazon.jsii.Kernel.get(this, "stateful", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusStatefulList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusVersionTargetList getVersionTarget() {
        return software.amazon.jsii.Kernel.get(this, "versionTarget", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatusVersionTargetList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.compute_region_instance_group_manager.ComputeRegionInstanceGroupManagerStatus value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
